@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2022 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -10,12 +10,14 @@
 #include <QVBoxLayout>
 
 #include <QDialogButtonBox>
+#include <QStandardPaths>
 #include <QTest>
 QTEST_MAIN(QuickTextConfigureDialogTest)
 
 QuickTextConfigureDialogTest::QuickTextConfigureDialogTest(QObject *parent)
     : QObject(parent)
 {
+    QStandardPaths::setTestModeEnabled(true);
 }
 
 void QuickTextConfigureDialogTest::shouldHaveDefaultValues()
