@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
   SPDX-FileCopyrightText: 2009 Constantin Berzan <exit3219@gmail.com>
 
   Based on MailTransport code by:
@@ -55,7 +55,7 @@ void SendmailConfigWidget::init()
         // is saved in the config.
         d->ui.kcfg_host->setText(QStandardPaths::findExecutable(QStringLiteral("sendmail")));
     }
-    connect(d->ui.kcfg_host->lineEdit(), qOverload<const QString &>(&QLineEdit::textChanged), this, &SendmailConfigWidget::slotTextChanged);
+    connect(d->ui.kcfg_host->lineEdit(), &QLineEdit::textChanged, this, &SendmailConfigWidget::slotTextChanged);
     slotTextChanged(d->ui.kcfg_host->text());
 }
 
