@@ -24,17 +24,17 @@ void DKIMPolicyWidgetTest::shouldHaveDefaultValues()
     auto mainLayout = w.findChild<QVBoxLayout *>(QStringLiteral("mainLayout"));
     QVERIFY(mainLayout);
 
-    auto mVerifyIfEmailMustBeSigned = w.findChild<QCheckBox *>(QStringLiteral("mVerifyIfEmailMustBeSigned"));
+    auto mVerifyIfEmailMustBeSigned = w.findChild<QCheckBox *>(QStringLiteral("kcfg_CheckIfEmailShouldBeSigned"));
     QVERIFY(mVerifyIfEmailMustBeSigned);
     QVERIFY(!mVerifyIfEmailMustBeSigned->text().isEmpty());
     QVERIFY(mVerifyIfEmailMustBeSigned->isEnabled());
 
-    auto mUseDMARC = w.findChild<QCheckBox *>(QStringLiteral("mUseDMARC"));
+    auto mUseDMARC = w.findChild<QCheckBox *>(QStringLiteral("kcfg_UseDMarc"));
     QVERIFY(mUseDMARC);
     QVERIFY(!mUseDMARC->text().isEmpty());
     QVERIFY(!mUseDMARC->isEnabled());
 
-    auto mUseDefaultRules = w.findChild<QCheckBox *>(QStringLiteral("mUseDefaultRules"));
+    auto mUseDefaultRules = w.findChild<QCheckBox *>(QStringLiteral("kcfg_UseDefaultRules"));
     QVERIFY(mUseDefaultRules);
     QVERIFY(!mUseDefaultRules->text().isEmpty());
     QVERIFY(!mUseDefaultRules->isEnabled());
@@ -44,17 +44,17 @@ void DKIMPolicyWidgetTest::shouldHaveDefaultValues()
     QVERIFY(!mRulesButton->isEnabled());
     QVERIFY(!mRulesButton->text().isEmpty());
 
-    auto mAutoGenerateRule = w.findChild<QCheckBox *>(QStringLiteral("mAutoGenerateRule"));
+    auto mAutoGenerateRule = w.findChild<QCheckBox *>(QStringLiteral("kcfg_AutogenerateRule"));
     QVERIFY(mAutoGenerateRule);
     QVERIFY(!mAutoGenerateRule->text().isEmpty());
     QVERIFY(!mAutoGenerateRule->isEnabled());
 
-    auto mReadAuthResultHeader = w.findChild<QCheckBox *>(QStringLiteral("mReadAuthResultHeader"));
+    auto mReadAuthResultHeader = w.findChild<QCheckBox *>(QStringLiteral("kcfg_UseAuthenticationResults"));
     QVERIFY(mReadAuthResultHeader);
     QVERIFY(!mReadAuthResultHeader->text().isEmpty());
     QVERIFY(!mReadAuthResultHeader->isEnabled());
 
-    auto mAutoGenerateOnlyIfSenderInSDID = w.findChild<QCheckBox *>(QStringLiteral("mAutoGenerateOnlyIfSenderInSDID"));
+    auto mAutoGenerateOnlyIfSenderInSDID = w.findChild<QCheckBox *>(QStringLiteral("kcfg_AutogenerateRuleOnlyIfSenderOnSDID"));
     QVERIFY(mAutoGenerateOnlyIfSenderInSDID);
     QVERIFY(!mAutoGenerateOnlyIfSenderInSDID->text().isEmpty());
     QVERIFY(!mAutoGenerateOnlyIfSenderInSDID->isEnabled());
